Skip to contents

For now, we will just keep this blank It is a function here so that one day we can use the ANDES relative abundance category But it is not used for commercial stocks, so we skip it

Usage

format_cod_descrip_capt(capt)

Arguments

capt

Dataframe