Skip to contents

this function is meant to help the validation automatically getting colnames, no-null cols and datatypes. but I cannot get it to work here yet... (but works in Dbeaver)

Usage

get_access_table_properties(table_name = NULL)

Arguments

table_name

The name of the table