Get a list of legal collection names as a filter for get_biometrie_petoncle()
get_legal_collection_names.RdThese must match the shared_models_observationgroup.nom as the ANDES collection. The secteur (16E, 16F, centre, ouest) are taken from the last part of the string.