Skip to contents

Add the cod_serie_hist to the whole dataframe This value is not present in ANDES so it will have to be specified here. Run this without desc_serie_hist_f to get a list of choices.

Usage

init_cod_serie_hist(df, desc_serie_hist_f = NULL)

Arguments

df

Dataframe

desc_serie_hist_f

String