Skip to contents

Perform database validation checks on the dataframe

Usage

validate_projet_mollusque(df)

Arguments

df

The dataframe to validate

Value

Boolean representing if all the validation tests have passed

Details

This compares the dataframe columns and values to the requirements of the database