validate_trait_mollusque.Rd
Perform database validation checks on the dataframe
validate_trait_mollusque(df)
The dataframe to validate
Boolean representing if all the validation tests have passed
This compares the dataframe columns and values to the requirements of the database