Checks if all dataframe cols named in the col_names contain NA This is useful to validate if a dataframe can be written to a DB table (where some columns values cannot be null)
check_cols_contains_na.RdChecks if all dataframe cols named in the col_names contain NA This is useful to validate if a dataframe can be written to a DB table (where some columns values cannot be null)