format_cod_typ_mesure.Rd
format COD_TYP_MESURE
format_cod_typ_mesure(capt)
Dataframe For now, we will just assume all data is quantitative since we are limiting ourselves to commercial (scallops and whelk). One day, this function should be generalized to also lookup the data and determine it.