get database table properties
get_access_table_properties.Rdthis function is meant to help the validation automatically getting colnames, no-null cols and datatypes. but I cannot get it to work here yet... (but works in Dbeaver)
get_access_table_properties.Rdthis function is meant to help the validation automatically getting colnames, no-null cols and datatypes. but I cannot get it to work here yet... (but works in Dbeaver)