Gets engin_mollusc (formatted results)
get_engin_mollusque.RdThis function executes a SQL query to retrieve the needed andes data to construct the ENGIN_MOLLUSC table. The current ANDES active mission will determine for which data are returned.
get_engin_mollusque.RdThis function executes a SQL query to retrieve the needed andes data to construct the ENGIN_MOLLUSC table. The current ANDES active mission will determine for which data are returned.