This fetches the specimen-level coverage data and coverts it to an average set-level metric in accordance to the legacy Oracle database.
get_epibiont.RdThis fetches the specimen-level coverage data and coverts it to an average set-level metric in accordance to the legacy Oracle database.