Gets fishing projet_mollusque (formatted results)
get_projet_mollusque.RdThis function executes a SQL query to retrieve the needed andes data to construct the PROJET_MOLLUSQUE table. The current ANDES active mission will determine for which data are returned.