Sanitize value to SQL statement
sanitize_sql_value.RdIt will wrap string with an extra set of single quotes. It will escape every single quote by doubling it up This usualy does nothing to the value itself except inject the NULL string for NA/null and empty strings