Validate set result consistency
validate_set_result.RdANDES has a mecanism to tag valid sets, but we also inserted a legacy set observation for a similar reason. This functions makes sure both point in the same direction and prints an error code if there are contradictions.